deeplake.api.link_tiled
=======================
.. currentmodule:: deeplake.api.link_tiled
.. function::  link_tiled(path_array: np.ndarray, creds_key: Optional[str] = None) -> LinkedTiledSample:

    See :func:`deeplake.link_tiled`.